@@ -9,7 +9,7 @@ use 5.006;
 
 use vars (qw($VERSION $Tolerance $Min_samples_number));
 
-$VERSION = '3.0606';
+$VERSION = '3.0608';
 
 $Tolerance = 0.0;
 $Min_samples_number = 4;
@@ -18,7 +18,7 @@ package Statistics::Descriptive::Sparse;
 
 use vars qw($VERSION);
 
-$VERSION = '3.0606';
+$VERSION = '3.0608';
 
 use vars qw(%fields);
 use Carp;
@@ -238,7 +238,7 @@ package Statistics::Descriptive::Full;
 
 use vars qw($VERSION);
 
-$VERSION = '3.0606';
+$VERSION = '3.0608';
 
 use Carp;
 use POSIX ();
@@ -248,8 +248,8 @@ use vars qw(@ISA $a $b %fields);
 
 @ISA = qw(Statistics::Descriptive::Sparse);
 
-use List::MoreUtils;
-use List::Util;
+use List::MoreUtils ();
+use List::Util ();
 
 ##Create a list of fields not to remove when data is updated
 %fields = (
@@ -823,12 +823,11 @@ sub skewness {
             my $mean = $self->mean();
 
             my $sum_pow3;
-
             foreach my $rec ( $self->get_data ) {
-                my $value  = (($rec - $mean) / $sd);
-                $sum_pow3 +=  $value ** 3;
+                $sum_pow3 += (($rec - $mean) / $sd) ** 3;
             }
 
+
             my $correction = $n / ( ($n-1) * ($n-2) );
 
             $skew = $correction * $sum_pow3;
@@ -848,7 +847,7 @@ sub kurtosis {
         my $kurt;
 
         my $n  = $self->count();
-        my $sd   = $self->standard_deviation();
+        my $sd = $self->standard_deviation();
 
         if ( $sd && $n > 3) {
 
